pub fn from_path(path: impl AsRef<Path>) -> Option<LanguageEntry>Expand description
Look up a language by file path, using its extension.
pub fn from_path(path: impl AsRef<Path>) -> Option<LanguageEntry>Look up a language by file path, using its extension.